@@ -4,7 +4,7 @@
 // Author:      Stefan Csomor
 // Modified by:
 // Created:     1998-01-01
-// RCS-ID:      $Id: treectrl.cpp,v 1.15 2006/03/24 23:46:35 ABX Exp $
+// RCS-ID:      $Id: treectrl.cpp 45232 2007-04-03 02:44:32Z PC $
 // Copyright:   (c) Stefan Csomor
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -29,14 +29,17 @@ wxTreeCtrl::wxTreeCtrl()
 
 bool wxTreeCtrl::Create(wxWindow *parent,
     wxWindowID id, const wxPoint& pos, const wxSize& size,
-    long style, const wxValidator& validator, const wxString& name)
+    long style, const wxValidator& wxVALIDATOR_PARAM(validator),
+    const wxString& name)
 {
     m_imageListNormal = NULL;
     m_imageListState = NULL;
     m_textCtrl = NULL;
 
     SetName(name);
+#if wxUSE_VALIDATORS
     SetValidator(validator);
+#endif
     SetParent(parent);
 
     m_windowStyle = style;
