@@ -4,7 +4,7 @@
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: menu.cpp,v 1.65 2006/08/19 23:21:18 VZ Exp $
+// RCS-ID:      $Id: menu.cpp 50982 2008-01-01 20:38:33Z VZ $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -33,8 +33,6 @@
 
 #ifdef __VMS__
 #pragma message disable nosimpint
-#define XtDisplay XTDISPLAY
-#define XtWindow XTWINDOW
 #endif
 #include <Xm/Label.h>
 #include <Xm/LabelG.h>
@@ -234,6 +232,8 @@ void wxMenuBar::SetLabelTop(size_t pos, const wxString& label)
     if ( !menu )
         return;
 
+    m_titles[pos] = label;
+
     Widget w = (Widget)menu->GetButtonWidget();
     if (w)
     {
@@ -247,6 +247,8 @@ void wxMenuBar::SetLabelTop(size_t pos, const wxString& label)
 
 wxString wxMenuBar::GetLabelTop(size_t pos) const
 {
+    return wxStripMenuCodes(m_titles[pos]);
+#if 0
     wxMenu *menu = GetMenu(pos);
     if ( menu )
     {
@@ -263,8 +265,19 @@ wxString wxMenuBar::GetLabelTop(size_t pos) const
     }
 
     return wxEmptyString;
+#endif
 }
 
+// Gets the original label at the top-level of the menubar
+wxString wxMenuBar::GetMenuLabel(size_t pos) const
+{
+    wxCHECK_MSG( pos < GetMenuCount(), wxEmptyString,
+                 wxT("invalid menu index in wxMenuBar::GetMenuLabel") );
+
+    return m_titles[pos];
+}
+
+
 bool wxMenuBar::Append(wxMenu * menu, const wxString& title)
 {
     return Insert(GetMenuCount(), menu, title);
