@@ -4,7 +4,7 @@
 // Author:      David Webster
 // Modified by:
 // Created:     10/27/99
-// RCS-ID:      $Id: frame.cpp 43350 2006-11-12 16:06:07Z SN $
+// RCS-ID:      $Id: frame.cpp 53096 2008-04-09 21:25:28Z SN $
 // Copyright:   (c) David Webster
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -54,6 +54,12 @@ END_EVENT_TABLE()
 
 IMPLEMENT_DYNAMIC_CLASS(wxFrame, wxWindow)
 
+#if wxUSE_MINIFRAME
+#include "wx/minifram.h"
+IMPLEMENT_DYNAMIC_CLASS(wxMiniFrame, wxFrame)
+#endif // wxUSE_MINIFRAME
+
+
 // ============================================================================
 // implementation
 // ============================================================================
